@@ -3,23 +3,15 @@ QuickMongo.py
 By Science Spot from Decimal Developement
 
 Simple wrapper for PyMongo written in python!
-v0.0.2
+v0.0.6
 """
 
-# v0.0.2
-__version__ ='0.0.2'
+# v0.0.6
+__version__ ='0.0.6'
 
 # Import mongo client from pymongo
 from pymongo import MongoClient
 
-# Import time package
-from time import time
-
-# Default Options
-defaultOptions = {
-    'collection_name': 'python'
-}
-
 # Util Class
 
 class Util():
@@ -39,7 +31,7 @@ class Util():
 class Base():
 
     # Constructor Class
-    def __init__(self, client, options: dict = defaultOptions):
+    def __init__(self, client, options: dict = {}):
         self.client = client
         self.db = self.client[options['db_name']]
         self.options = options
@@ -92,7 +84,7 @@ class Base():
 # Database Class which is the main class
 class Database():
 
-    def __init__(self, mongoURL: str, options: dict = defaultOptions):
+    def __init__(self, mongoURL: str, options: dict = {}):
         try:
             self.client = MongoClient(mongoURL)
         except:
@@ -105,6 +97,9 @@ class Database():
         elif options['db_name'] not in database_names:
             raise TypeError('try to choose a db from here: ' + database_names)
 
+        if 'collection_name' not in options.keys():
+            options['collection_name'] = 'python'
+
         self.base = Base(self.client, options)
         self.options = options
         self.client = self.base.client
